#!/usr/bin/env bash

cd "$(dirname "$0")"

# turn on verbose debugging output for parabuild logs.
exec 4>&1; export BASH_XTRACEFD=4; set -x
# make errors fatal
set -e
# complain about unset env variables
set -u

if [ -z "$AUTOBUILD" ] ; then 
    exit 1
fi

if [ "$OSTYPE" = "cygwin" ] ; then
    autobuild="$(cygpath -u $AUTOBUILD)"
else
    autobuild="$AUTOBUILD"
fi

top="$(pwd)"
stage="$(pwd)/stage"

mkdir -p $stage

# Load autobuild provided shell functions and variables
source_environment_tempfile="$stage/source_environment.sh"
"$autobuild" source_environment > "$source_environment_tempfile"
. "$source_environment_tempfile"

ABSEIL_CPP_VERSION="ac78ffc"
ABSEIL_CPP_SOURCE_DIR="abseil-cpp"

build=${AUTOBUILD_BUILD_ID:=0}

echo "${ABSEIL_CPP_VERSION}.${build}" > "${stage}/VERSION.txt"

# Create the staging folders
mkdir -p "$stage/abseil-cpp"

pushd "$ABSEIL_CPP_SOURCE_DIR"
    case "$AUTOBUILD_PLATFORM" in

        # ------------------------ windows, windows64 ------------------------
        common*)
            cp -a * "$stage/abseil-cpp/"
        ;;
    esac
    mkdir -p "$stage/LICENSES"
    cp LICENSE "$stage/LICENSES/abseil-cpp.txt"
popd
